==> speck-0.0.1.tgz: package/spec/klient-spec.js <==
var vows = require('vows')
  , assert = require('assert')
  , events = require('events')
  , Klient = require('../lib/klient')
  , batches, server, suite

// vows
batches = [
  { 'init without server': {
      topic: function() {
        return new Klient()
      },
      'when api method called': {
        topic: function(client) {
          return client.get({ path: '/' })
        },
        'should throw a reference exception': function(err, res) {
          assert.throws(function() {
            throw new Error(err)
          }, Error)
          assert.isUndefined(res)
        }
      }
    }
  },
  { 'init with server': {
      topic: function() {
        return new Klient({ server: createServer() })
      },
      'when get is called': {
        topic: function(client) {
          return client.get({ path: '/' })
        },
        'should respond': function(err, res) {
          assert.isNull(err)
          assert.equal(res.body, 'OK')
        }
      },
      'when post is called': {
        topic: function(client) {
          return client.post({ path: '/' })
        },
        'should respond': function(err, res) {
          assert.isNull(err)
          assert.equal(res.body, 'OK')
        }
      },
      'when put is called': {
        topic: function(client) {
          return client.put({ path: '/' })
        },
        'should respond': function(err, res) {
          assert.isNull(err)
          assert.equal(res.body, 'OK')
        }
      },
      'when del is called': {
        topic: function(client) {
          return client.del({ path: '/' })
        },
        'should respond': function(err, res) {
          assert.isNull(err)
          assert.equal(res.body, 'OK')
        }
      }
    }
  }
]

suite = vows.describe('KLIENT')

batches.forEach(function(batch) {
  suite.addBatch(batch)
})

suite.export(module)

// fixtures & helpers
function createServer() {
  server = new(require('http').Server)

  server.on('request', function(req, res) {
    var body = 'OK'

    req.on('end', function() {
      res.writeHead(200, {
        'content-length': body.length,
        'content-type': 'text/plain'
      })
      res.end(body)
    })
  })

  return server
}

==> speck-0.0.3.tgz: package/spec/klient-spec.js <==
var vows = require('vows')
  , assert = require('assert')
  , events = require('events')
  , Klient = require('../lib/klient')
  , batches, server, suite

// vows
batches = [
  { 'init without server': {
      topic: function() {
        return new Klient()
      },
      'when api method called': {
        topic: function(client) {
          return client.get({ path: '/' })
        },
        'should throw a reference exception': function(err, res) {
          assert.throws(function() {
            throw new Error(err)
          }, Error)
          assert.isUndefined(res)
        }
      }
    }
  },
  { 'init with server': {
      topic: function() {
        return new Klient({ server: createServer() })
      },
      'when get is called': {
        topic: function(client) {
          return client.get({ path: '/' })
        },
        'should respond': function(err, res) {
          assert.isNull(err)
          assert.equal(res.body, 'get')
        }
      },
      'when post is called': {
        topic: function(client) {
          return client.post({ path: '/' })
        },
        'should respond': function(err, res) {
          assert.isNull(err)
          assert.equal(res.body, 'post')
        }
      },
      'when put is called': {
        topic: function(client) {
          return client.put({ path: '/' })
        },
        'should respond': function(err, res) {
          assert.isNull(err)
          assert.equal(res.body, 'put')
        }
      },
      'when del is called': {
        topic: function(client) {
          return client.del({ path: '/' })
        },
        'should respond': function(err, res) {
          assert.isNull(err)
          assert.equal(res.body, 'delete')
        }
      }
    }
  }
]

suite = vows.describe('KLIENT')

batches.forEach(function(batch) {
  suite.addBatch(batch)
})

suite.export(module)

// fixtures & helpers
function createServer() {
  server = new(require('http').Server)

  server.on('request', function(req, res) {
    var body = req.method.toLowerCase()

    req.on('end', function() {
      res.writeHead(200, {
        'content-length': body.length,
        'content-type': 'text/plain'
      })
      res.end(body)
    })
  })

  return server
}
